==> medapay-0.1.2.tar.gz: lib/src/components/payment_action_bar.dart <==
import 'package:flutter/material.dart';

class PaymentActionBar extends StatelessWidget {
  final String title;
  final double amount;
  final String description;
  final Function onCancel;
  final Function onContinue;
  final bool isActive;

  const PaymentActionBar(
      {Key key,
      this.title,
      this.amount,
      this.description,
      this.onCancel,
      this.isActive,
      this.onContinue})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Positioned(
      bottom: 0,
      left: 0,
      right: 0,
      child: Container(
        padding: EdgeInsets.all(20.0),
        decoration: BoxDecoration(
          color: Colors.white,
          boxShadow: [
            BoxShadow(
              color: Colors.grey,
              offset: Offset(0.0, 1.0), //(x,y)
              blurRadius: 6.0,
            ),
          ],
        ),
        child: Column(
          mainAxisSize: MainAxisSize.max,
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Expanded(
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Text(title,
                          textAlign: TextAlign.left,
                          style: TextStyle(
                              fontSize: 18.0,
                              height: 1.4,
                              fontWeight: FontWeight.w600,
                              color: Colors.black)),
                      Text(description,
                          textAlign: TextAlign.left,
                          softWrap: true,
                          style: TextStyle(
                              fontSize: 14.0,
                              height: 1.3,
                              fontWeight: FontWeight.w500,
                              color: Color(0xFF8F9BAA)))
                    ],
                  ),
                ),
                SizedBox(
                  width: 20,
                ),
                Column(
                  crossAxisAlignment: CrossAxisAlignment.end,
                  children: [
                    Text("$amount Br.",
                        textAlign: TextAlign.right,
                        style: TextStyle(
                            fontSize: 26.0,
                            fontWeight: FontWeight.w600,
                            color: Color(0xFFF56A05)))
                  ],
                ),
              ],
            ),
            Divider(
              thickness: 2.0,
              height: 28,
            ),
            Row(
              children: [
                OutlineButton(
                  padding: EdgeInsets.symmetric(horizontal: 24, vertical: 14),
                  shape: RoundedRectangleBorder(
                      borderRadius: BorderRadius.circular(6)),
                  onPressed: () {
                    if (onCancel != null) {
                      onCancel();
                    }
                    Navigator.pop(context);
                  },
                  borderSide: BorderSide(color: Color(0xff707070), width: 2),
                  child: Text("Cancel",
                      style: TextStyle(
                          fontSize: 18.0,
                          fontWeight: FontWeight.w600,
                          color: Color(0xFF605A5A))),
                ),
                SizedBox(width: 15.0),
                Expanded(
                  child: MaterialButton(
                    padding: EdgeInsets.symmetric(horizontal: 30, vertical: 14),
                    onPressed: isActive ? onContinue : null,
                    height: 50.0,
                    textColor: Colors.white,
                    color: Color(0xFF0ABA2B),
                    shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(6)),
                    child: Text("Continue",
                        style: TextStyle(
                          fontSize: 18.0,
                          fontWeight: FontWeight.w600,
                        )),
                  ),
                )
              ],
            )
          ],
        ),
      ),
    );
  }
}

==> medapay-0.1.3.tar.gz: lib/src/components/payment_action_bar.dart <==
import 'package:flutter/material.dart';

class PaymentActionBar extends StatelessWidget {
  final String title;
  final double amount;
  final String description;
  final Function onCancel;
  final Function onContinue;
  final bool isActive;

  const PaymentActionBar(
      {Key key,
      this.title,
      this.amount,
      this.description,
      this.onCancel,
      this.isActive,
      this.onContinue})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Positioned(
      bottom: 0,
      left: 0,
      right: 0,
      child: Container(
        padding: EdgeInsets.all(20.0),
        decoration: BoxDecoration(
          color: Colors.white,
          boxShadow: [
            BoxShadow(
              color: Colors.grey,
              offset: Offset(0.0, 1.0), //(x,y)
              blurRadius: 6.0,
            ),
          ],
        ),
        child: Column(
          mainAxisSize: MainAxisSize.max,
          children: [
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Expanded(
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      Text(title,
                          textAlign: TextAlign.left,
                          style: TextStyle(
                              fontSize: 18.0,
                              height: 1.4,
                              fontWeight: FontWeight.w600,
                              color: Colors.black)),
                      Text(description,
                          textAlign: TextAlign.left,
                          softWrap: true,
                          style: TextStyle(
                              fontSize: 14.0,
                              height: 1.3,
                              fontWeight: FontWeight.w500,
                              color: Color(0xFF8F9BAA)))
                    ],
                  ),
                ),
                SizedBox(
                  width: 20,
                ),
                Column(
                  crossAxisAlignment: CrossAxisAlignment.end,
                  children: [
                    Text("$amount Br.",
                        textAlign: TextAlign.right,
                        style: TextStyle(
                            fontSize: 26.0,
                            fontWeight: FontWeight.w600,
                            color: Color(0xFFF56A05)))
                  ],
                ),
              ],
            ),
            Divider(
              thickness: 2.0,
              height: 28,
            ),
            Row(
              children: [
                OutlineButton(
                  padding: EdgeInsets.symmetric(horizontal: 24, vertical: 14),
                  shape: RoundedRectangleBorder(
                      borderRadius: BorderRadius.circular(6)),
                  onPressed: () {
                    if (onCancel != null) {
                      onCancel();
                    }
                    // Navigator.pop(context);
                  },
                  borderSide: BorderSide(color: Color(0xff707070), width: 2),
                  child: Text("Cancel",
                      style: TextStyle(
                          fontSize: 18.0,
                          fontWeight: FontWeight.w600,
                          color: Color(0xFF605A5A))),
                ),
                SizedBox(width: 15.0),
                Expanded(
                  child: MaterialButton(
                    padding: EdgeInsets.symmetric(horizontal: 30, vertical: 14),
                    onPressed: isActive ? onContinue : null,
                    height: 50.0,
                    textColor: Colors.white,
                    color: Color(0xFF0ABA2B),
                    shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(6)),
                    child: Text("Continue",
                        style: TextStyle(
                          fontSize: 18.0,
                          fontWeight: FontWeight.w600,
                        )),
                  ),
                )
              ],
            )
          ],
        ),
      ),
    );
  }
}
